@@ -44,22 +44,21 @@
    - Code clean up: removed all subroutines that were unused.
 */
 
-#define USE_FC_LEN_T
+#ifndef  USE_FC_LEN_T
+# define USE_FC_LEN_T
+#endif
 #include <Rconfig.h>
 #include <Rmath.h>
 #include <complex.h>
-// #include <R.h>
-
 #include <R_ext/BLAS.h>
-#include <R_ext/Applic.h>
 #include <R_ext/Lapack.h>
+#include <R_ext/Applic.h>
 
 #ifndef FCONE
 # define FCONE
 #endif
 
 #include "RobStatTM.h"
-//-> <R.h>, <Rinternals.h>  -> XLENGTH, R_xlen_t
 
 
 /* these  will also move to "lmrob.h" ---
@@ -232,19 +231,8 @@ void zero_mat(double **a, int n, int m);
 	Rprintf(" Optimal block size for DGELS: %d\n", lwork); \
                                                                 \
     /* allocate */                                              \
-    work =    (double *) Calloc(lwork, double);                 \
-    weights = (double *) Calloc(n,     double);
-
-#define CLEANUP_WLS                                             \
-    Free(work); Free(weights);
-
-#define CLEANUP_EQUILIBRATION                                   \
-    Free(Dr); Free(Dc); Free(Xe);
-
-#define CLEANUP_SUBSAMPLE                                       \
-    Free(ind_space); Free(idc); Free(idr); Free(pivot);         \
-    Free(lu); Free(v);                                          \
-    CLEANUP_EQUILIBRATION;
+    work =    (double *) R_alloc(lwork, sizeof(double));                 \
+    weights = (double *) R_alloc(n,     sizeof(double));
 
 #define FIT_WLS(_X_, _x_, _y_, _n_, _p_)			\
     /* add weights to _y_ and _x_ */                            \
@@ -259,14 +247,12 @@ void zero_mat(double **a, int n, int m);
 		    &_n_, work, &lwork, &info FCONE);                 \
     if (info) {					                \
 	if (info < 0) {                                         \
-	    CLEANUP_WLS;					\
 	    error("DGELS: illegal argument in %i. argument.", info); \
 	} else {                                                \
 	    if (trace_lev >= 4) {				\
 		Rprintf(" Robustness weights in failing step: ");	\
 		disp_vec(weights, _n_);				\
 	    }                                                   \
-	    CLEANUP_WLS;					\
 	    error("DGELS: weighted design matrix not of full rank (column %d).\nUse control parameter 'trace.lev = 4' to get diagnostic output.", info); \
 	}                                                       \
     }
@@ -279,15 +265,14 @@ void zero_mat(double **a, int n, int m);
     /*     Section 2.5.2 Equilibration                      */  \
     double *Dr, *Dc, *Xe, rowcnd, colcnd, amax;			\
     int rowequ = 0 , colequ = 0;                                \
-    Dr =        (double *) Calloc(_n_,     double);             \
-    Dc =        (double *) Calloc(_p_,     double);             \
-    Xe =        (double *) Calloc(_n_*_p_, double);             \
+    Dr =        (double *) R_alloc(_n_,     sizeof(double));             \
+    Dc =        (double *) R_alloc(_p_,     sizeof(double));             \
+    Xe =        (double *) R_alloc(_n_*_p_, sizeof(double));             \
     COPY(_X_, Xe, _n_*_p_);                                     \
     F77_CALL(dgeequ)(&_n_, &_p_, Xe, &_n_, Dr, Dc, &rowcnd,	\
     		     &colcnd, &amax, &info);                    \
     if (info) {                                                 \
 	if (info < 0) {                                         \
-	    CLEANUP_EQUILIBRATION;				\
 	    error("DGEEQ: illegal argument in %i. argument", -1 * info); \
 	} else if (info > _n_) {                                \
 	    if (_large_n_) {                                    \
@@ -313,12 +298,12 @@ void zero_mat(double **a, int n, int m);
     /* (Pointers to) Arrays - to be allocated */                \
     int *ind_space, *idc, *idr, *pivot;				\
     double *lu, *v;						\
-    ind_space = (int *)    Calloc(_n_,     int);                \
-    idc =       (int *)    Calloc(_n_,     int);                \
-    idr =       (int *)    Calloc(_p_,     int);                \
-    pivot =     (int *)    Calloc(_p_-1,   int);                \
-    lu =        (double *) Calloc(_p_*_p_, double);             \
-    v =         (double *) Calloc(_p_,     double);             \
+    ind_space = (int *)    R_alloc(_n_,     sizeof(int));                \
+    idc =       (int *)    R_alloc(_n_,     sizeof(int));                \
+    idr =       (int *)    R_alloc(_p_,     sizeof(int));                \
+    pivot =     (int *)    R_alloc(_p_-1,   sizeof(int));                \
+    lu =        (double *) R_alloc(_p_*_p_, sizeof(double));             \
+    v =         (double *) R_alloc(_p_,     sizeof(double));             \
     SETUP_EQUILIBRATION(_n_, _p_, _X_, _large_n_);
 
 #define COPY(from, to, len) Memcpy(to, from, len)
@@ -531,7 +516,7 @@ void R_subsample(const double x[], const double y[], int *n, int *m,
     *_rowequ = rowequ;
     *_colequ = colequ;
 
-    CLEANUP_EQUILIBRATION;
+    // CLEANUP_EQUILIBRATION;
 
     PutRNGstate();
 }
@@ -1748,7 +1733,7 @@ Rboolean rwls(const double X[], const double y[], int n, int p,
 
     *max_it = iterations;
 
-    CLEANUP_WLS;
+    // CLEANUP_WLS;
 
     return converged;
 } /* rwls() */
@@ -1810,9 +1795,10 @@ void fast_s_large_n(double *X, double *y,
  * *bbeta  = final estimator
  * *sscale = associated scale estimator (or -1 when problem)
  */
-    int i,j,k, k2, it_k, ij, freedsamp = 0, initwls = 0;
+    int i, j, k2, it_k, ij;
     int n = *nn, p = *pp, kk = *K, ipsi = *iipsi;
     int groups = *ggroups, n_group = *nn_group, sg = groups * n_group;
+    int k = groups * *best_r;  
     double b = *bb, sc, best_sc, worst_sc;
     int pos_worst_scale;
     Rboolean conv;
@@ -1823,20 +1809,20 @@ void fast_s_large_n(double *X, double *y,
     double **final_best_betas, *final_best_scales;
 
 #define CALLOC_MAT(_M_, _n_, _d_)			\
-    _M_ = (double **) Calloc(_n_, double *);		\
-    for(int i=0; i < _n_; i++)				\
-	_M_[i] = (double *) Calloc(_d_, double)
-
-    beta_ref = (double *) Calloc(p, double);
+    _M_ = (double **) R_Calloc(_n_, double *);		\
+    for(int i=0; i < _n_; i++)				          \
+      _M_[i] = (double *) R_alloc(_d_, sizeof(double))
+      
+    beta_ref = (double *) R_alloc(p, sizeof(double));
     CALLOC_MAT(final_best_betas, *best_r, p);
-    final_best_scales = (double *) Calloc(*best_r, double);
+    final_best_scales = (double *) R_alloc(*best_r, sizeof(double));
     k = *best_r * groups;
-    best_scales = (double *) Calloc(k,	double );
+    best_scales = (double *) R_alloc(k,	sizeof(double));
     CALLOC_MAT(best_betas, k, p);
-    indices =   (int *)    Calloc(sg,   int);
-    ind_space = (int *)    Calloc(n,   int);
-    xsamp =     (double *) Calloc(n_group*p, double);
-    ysamp =     (double *) Calloc(n_group,   double);
+    indices =   (int *)    R_alloc(sg,   sizeof(int));
+    ind_space = (int *)    R_alloc(n,   sizeof(int));
+    xsamp =     (double *) R_alloc(n_group*p, sizeof(double));
+    ysamp =     (double *) R_alloc(n_group,   sizeof(double));
 
     /* assume that n > 2000 */
 
@@ -1848,7 +1834,7 @@ void fast_s_large_n(double *X, double *y,
     /* FIXME: define groups using nonsingular subsampling? */
     /*        would also need to allow observations to be part */
     /*        of multiple groups at the same time */
-    Free(ind_space);
+    // R_Free(ind_space);
     /* FIXME: Also look at lqs_setup(),
      * -----  and  xr[.,.] "fortran-like" matrix can be used from there!*/
 
@@ -1877,7 +1863,7 @@ void fast_s_large_n(double *X, double *y,
 	}
     }
 
-    Free(xsamp); Free(ysamp); freedsamp = 1;
+    // R_Free(xsamp); R_Free(ysamp); freedsamp = 1;
 #undef xsamp
 
 /* now	iterate (refine) these "best_r * groups"
@@ -1889,9 +1875,9 @@ void fast_s_large_n(double *X, double *y,
     res = (double *) R_alloc(n,   sizeof(double));
     wx =  (double *) R_alloc(n*p, sizeof(double)); // need only k here,
     wy =  (double *) R_alloc(n,   sizeof(double)); // but n in the last step
-    xsamp =     (double *) Calloc(sg*p, double);
-    ysamp =     (double *) Calloc(sg,   double);
-    freedsamp = 0;
+    xsamp =     (double *) R_alloc(sg*p, sizeof(double));
+    ysamp =     (double *) R_alloc(sg,   sizeof(double));
+    // freedsamp = 0;
 
 #define xsamp(_k_,_j_) xsamp[_j_*sg+_k_]
 
@@ -1903,7 +1889,7 @@ void fast_s_large_n(double *X, double *y,
 
     int lwork = -1, one = 1, info = 1;
     double work0, *work, *weights;
-    INIT_WLS(wx, wy, n, p); initwls = 1;
+    INIT_WLS(wx, wy, n, p); // initwls = 1;
 
     conv = FALSE;
     pos_worst_scale = 0;
@@ -1938,7 +1924,7 @@ void fast_s_large_n(double *X, double *y,
 	}
     }
 
-    Free(xsamp); Free(ysamp); freedsamp = 1;
+    // R_Free(xsamp); R_Free(ysamp); freedsamp = 1;
 
 /* now iterate the best "best_r"
  * betas in the whole sample until convergence (max_k, rel_tol)
@@ -1976,23 +1962,23 @@ void fast_s_large_n(double *X, double *y,
   cleanup_and_return:
     PutRNGstate();
 
-    Free(best_scales);
-    k = *best_r * groups;
-    for(i=0; i < k; i++) Free( best_betas[i] );
-    Free(best_betas); Free(indices);
-    for(i=0; i < *best_r; i++)
-	Free(final_best_betas[i]);
-    Free(final_best_betas);
-    Free(final_best_scales);
-    Free(beta_ref);
+    // R_Free(best_scales);
+    // k = *best_r * groups;
+    // for(i=0; i < k; i++) R_Free( best_betas[i] );
+    R_Free(best_betas); // R_Free(indices);
+//     for(i=0; i < *best_r; i++)
+// 	  R_Free(final_best_betas[i]);
+    R_Free(final_best_betas);
+    // R_Free(final_best_scales);
+    // R_Free(beta_ref);
 
-    if (freedsamp == 0) {
-	Free(xsamp); Free(ysamp);
-    }
+    // if (freedsamp == 0) {
+    // R_Free(xsamp); R_Free(ysamp);
+    // }
 
-    if (initwls) {
-	CLEANUP_WLS;
-    }
+    // if (initwls) {
+    // CLEANUP_WLS;
+    // }
 
 #undef X
 #undef xsamp
@@ -2038,14 +2024,14 @@ int fast_s_with_memory(double *X, double *y,
     SETUP_SUBSAMPLE(n, p, X, 1);
     INIT_WLS(X, y, n, p);
 
-    res	=       (double *) Calloc(n,   double);
-    wx =        (double *) Calloc(n*p, double);
-    wy =        (double *) Calloc(n,   double);
-    beta_cand = (double *) Calloc(p,   double);
-    beta_ref  = (double *) Calloc(p,   double);
+    res	=       (double *) R_alloc(n,   sizeof(double));
+    wx =        (double *) R_alloc(n*p, sizeof(double));
+    wy =        (double *) R_alloc(n,   sizeof(double));
+    beta_cand = (double *) R_alloc(p,   sizeof(double));
+    beta_ref  = (double *) R_alloc(p,   sizeof(double));
 
     for(i=0; i < *best_r; i++)
-	best_scales[i] = INFI;
+      best_scales[i] = INFI;
     pos_worst_scale = 0;
 
 /* resampling approximation  */
@@ -2090,11 +2076,13 @@ int fast_s_with_memory(double *X, double *y,
 
   cleanup_and_return:
 
-    CLEANUP_SUBSAMPLE;
-    CLEANUP_WLS;
-
-    Free(res); Free(wx); Free(wy);
-    Free(beta_cand); Free(beta_ref);
+    // CLEANUP_SUBSAMPLE;
+    // CLEANUP_WLS;
+    // 
+    // R_Free(res); R_Free(wx); R_Free(wy);
+    // R_Free(beta_cand); R_Free(beta_ref);
+    // R_Free(best_betas);
+    // R_Free(final_best_betas);
 
     return sing;
 } /* fast_s_with_memory() */
@@ -2143,14 +2131,14 @@ void fast_s(double *X, double *y,
     wx     = (double *) R_alloc(n*p, sizeof(double));
     wy     = (double *) R_alloc(n,   sizeof(double));
 
-    best_betas = (double **) Calloc(*best_r, double *);
-    best_scales = (double *) Calloc(*best_r, double);
+    best_betas = (double **) R_Calloc(*best_r, double *);
+    best_scales = (double *) R_alloc(*best_r, sizeof(double));
     for(i=0; i < *best_r; i++) {
-	best_betas[i] = (double*) Calloc(p, double);
+	best_betas[i] = (double*) R_alloc(p, sizeof(double));
 	best_scales[i] = INFI;
     }
-    beta_cand = (double *) Calloc(p, double);
-    beta_ref  = (double *) Calloc(p, double);
+    beta_cand = (double *) R_alloc(p, sizeof(double));
+    beta_ref  = (double *) R_alloc(p, sizeof(double));
 
     INIT_WLS(wx, wy, n, p);
 
@@ -2252,15 +2240,15 @@ void fast_s(double *X, double *y,
 
     PutRNGstate();
 
-    CLEANUP_SUBSAMPLE;
-    CLEANUP_WLS;
-
-    Free(best_scales);
-    Free(beta_cand);
-    Free(beta_ref);
-    for(i=0; i < *best_r; i++)
-	Free(best_betas[i]);
-    Free(best_betas);
+    // CLEANUP_SUBSAMPLE;
+    // CLEANUP_WLS;
+    // 
+    // R_Free(best_scales);
+    // R_Free(beta_cand);
+    // R_Free(beta_ref);
+    // for(i=0; i < *best_r; i++)
+    //   R_Free(best_betas[i]);
+    R_Free(best_betas);
 
     return;
 } /* fast_s() */
@@ -2440,7 +2428,7 @@ void m_s_subsample(double *X1, double *y, int n, int p1, int p2,
     }
 
   cleanup_and_return:
-    CLEANUP_SUBSAMPLE;
+    // CLEANUP_SUBSAMPLE;
     PutRNGstate();
 } /* m_s_subsample() */
 
@@ -2504,7 +2492,7 @@ Rboolean m_s_descent(double *X1, double *X2, double *y,
 			   NIT, K, KODE, SIGMA, t1, res2,
 			   SC1, SC2, SC3, SC4, BET0);
 	if (*KODE > 1) {
-	    CLEANUP_WLS;
+	    // CLEANUP_WLS;
 	    error("m_s_descent(): Problem in RLLARSBI (RILARS). KODE=%d. Exiting.",
 		  *KODE);
 	}
@@ -2559,7 +2547,7 @@ Rboolean m_s_descent(double *X1, double *X2, double *y,
 	maybe_SHOW_b1_b2;
     }
 
-    CLEANUP_WLS;
+    // CLEANUP_WLS;
 
     return converged;
 } /* m_s_descent() */
